/*******************************************************************************

  
  Copyright(c) 1999 - 2006 Intel Corporation. All rights reserved.
  
  This program is free software; you can redistribute it and/or modify it 
  under the terms of the GNU General Public License as published by the Free 
  Software Foundation; either version 2 of the License, or (at your option) 
  any later version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT 
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
  more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59 
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
  The full GNU General Public License is included in this distribution in the
  file called LICENSE.
  
  Contact Information:
  Linux NICS <linux.nics@intel.com>
  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497

*******************************************************************************/

#include <stdio.h>
#include "ethregs.h"


extern int clr;
extern int offset;

void dump_82598_registers(volatile void *mem, u32 size)
{
	unsigned int i, j, m, n;
	char name[24];

	for (i = 0; i < size; i += sizeof(u32)) {
		switch (i & 0xffffffff) {
		/* General Registers */
		case IXGBE_CTRL:
			sprintf(name, "CTRL"); break;
		case IXGBE_STATUS:	/* WO */
			sprintf(name, "STATUS"); break;
		case IXGBE_CTRL_EXT:
			sprintf(name, "CTRL_EXT"); break;
		case IXGBE_ESDP:
			sprintf(name, "ESDP"); break;
		case IXGBE_EODSDP:
			sprintf(name, "EODSDP"); break;
		case IXGBE_LEDCTL:
			sprintf(name, "LEDCTL"); break;
		case IXGBE_FRTIMER:
			sprintf(name, "FRTIMER"); break;
		case IXGBE_TCPTIMER:
			sprintf(name, "TCPTIMER"); break;

		/* NVM Registers */
		case IXGBE_EEC:
			sprintf(name, "EEC"); break;
		case IXGBE_EERD:
			sprintf(name, "EERD"); break;
		case IXGBE_FLA:
			sprintf(name, "FLA"); break;
		case IXGBE_EEMNGCTL:
			sprintf(name, "EEMNGCTL"); break;
		case IXGBE_EEMNGDATA:
			sprintf(name, "EEMNGDATA"); break;
		case IXGBE_FLMNGCTL:
			sprintf(name, "FLMNGCTL"); break;
		case IXGBE_FLMNGDATA:
			sprintf(name, "FLMNGDATA"); break;
		case IXGBE_FLMNGCNT:
			sprintf(name, "FLMNGCNT"); break;
		case IXGBE_FLOP:
			sprintf(name, "FLOP"); break;
		case IXGBE_GRC:
			sprintf(name, "GRC"); break;

		/* Interrupt Registers */
		case IXGBE_EICR:
			if (!clr) continue;
			sprintf(name, "EICR"); break;
		case IXGBE_EICS:	/* WO */
			sprintf(name, "EICS"); break;
		case IXGBE_EIMS:
			sprintf(name, "EIMS"); break;
		case IXGBE_EIMC:	/* WO */
			sprintf(name, "EIMC"); break;
		case IXGBE_EIAC:
			sprintf(name, "EIAC"); break;
		case IXGBE_EIAM:
			sprintf(name, "EIAM"); break;
		case IXGBE_EITR(0):
			for (j=i, n=0; n<19; n++) {
				sprintf(name, "EITR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_IVAR(0):
			for (j=i, n=0; n<25; n++) {
				sprintf(name, "IVAR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PBACL:
			sprintf(name, "PBACL"); break;
		case IXGBE_GPIE:
			sprintf(name, "GPIE"); break;

		/* Flow Control Registers */
		case IXGBE_PFCTOP:
			sprintf(name, "PFCTOP"); break;
		case IXGBE_FCTTV(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "FCTTV[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCRTL(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "FCRTL[%d]", n);
				printit32(j, name, mem);
				j += (2 * sizeof(u32));
			}
			continue;
		case IXGBE_FCRTH(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "FCRTH[%d]", n);
				printit32(j, name, mem);
				j += (2 * sizeof(u32));
			}
			continue;
		case IXGBE_FCRTV:
			sprintf(name, "FCRTV"); break;
		case IXGBE_TFCS:
			sprintf(name, "TFCS"); break;

		/* Receive DMA Registers */
		case IXGBE_RDBAL(0):
			for (j=i, n=0; n<64; n++) {
				sprintf(name, "RDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "RDLEN[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "RDH[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "RDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "RXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 24;
			}
			continue;
		case IXGBE_SRRCTL(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "SRRCTL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_DCA_RXCTRL(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "DCA_RXCTRL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RDRXCTL:
			sprintf(name, "RDRXCTL"); break;
		case IXGBE_RXPBSIZE(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXPBSIZE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXCTRL:
			sprintf(name, "RXCTRL"); break;
		case IXGBE_DROPEN:
			sprintf(name, "DROPEN"); break;

		/* Receive Registers */
		case IXGBE_RXCSUM:
			sprintf(name, "RXCSUM"); break;
		case IXGBE_RFCTL:
			sprintf(name, "RFCTL"); break;
		case IXGBE_MTA(0):
			for (j=i, n=0; n<128; n++) {
				sprintf(name, "MTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RAL(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "RAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "RAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PSRTYPE:
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "PSRTYPE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_VFTA(0):
			for (j=i, n=0; n<640; n++) {
				sprintf(name, "VFTA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FCTRL:
			sprintf(name, "FCTRL"); break;
		case IXGBE_VLNCTRL:
			sprintf(name, "VLNCTRL"); break;
		case IXGBE_MCSTCTRL:
			sprintf(name, "MCSTCTRL"); break;
		case IXGBE_MRQC:
			sprintf(name, "MRQC"); break;
		case IXGBE_VMD_CTL:
			sprintf(name, "VMD_CTL"); break;
		case IXGBE_IMIR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "IMIR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_IMIREXT(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "IMIREXT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_IMIRVP:
			sprintf(name, "IMIRVP"); break;
		case IXGBE_RETA(0):
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "RETA[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RSSRK(0):
			for (j=i, n=0; n<10; n++) {
				sprintf(name, "RSSRK[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Transmit DMA registers */
		case IXGBE_TDBAL(0):
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "TDBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDLEN[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "TDH[%d]", n);
				printit32(j, name, mem);
				j += 8;
				sprintf(name, "TDT[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "TXDCTL[%d]", n);
				printit32(j, name, mem);
				j += 16;
				sprintf(name, "TDWBAL[%d]", n);
				printit32(j, name, mem);
				j += 4;
				sprintf(name, "TDWBAH[%d]", n);
				printit32(j, name, mem);
				j += 4;
			}
			continue;
		case IXGBE_DTXCTL:
			sprintf(name, "DTXCTL"); break;
		case IXGBE_DCA_TXCTRL(0):
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "DCA_TXCTRL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TIPG:
			sprintf(name, "TIPG"); break;
		case IXGBE_TXPBSIZE(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXPBSIZE[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MNGTXMAP:
			sprintf(name, "MNGTXMAP"); break;

		/* Wake up registers */
		case IXGBE_WUC:
			sprintf(name, "WUC"); break;
		case IXGBE_WUFC:
			sprintf(name, "WUFC"); break;
		case IXGBE_WUS:
			sprintf(name, "WUS"); break;
		case IXGBE_IPAV:
			sprintf(name, "IPAV"); break;
		case IXGBE_IP4AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP4AT[%d]", n);
				printit32(j, name, mem);
				j += (2 * sizeof(u32));
			}
			continue;
		case IXGBE_IP6AT:
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "IP6AT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_WUPL:
			sprintf(name, "WUPL"); break;
		case IXGBE_WUPM:
			for (j=i, n=0; n<32; n++) {
				sprintf(name, "WUPM[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FHFT:
			for (j=i, m=0; m<4; m++) {
				for (n=0; n<32; n++) {
					sprintf(name, "FHFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					n++;
					sprintf(name, "FHFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					sprintf(name, "FHFT[%d] Mask[%d:%d]", m,
					        (n*4+3), ((n-1)*4));
					printit8(j, name, mem);
					j += sizeof(u32);
					if (n == 31) {
						sprintf(name, "FHFT[%d] Length", m);
						printit32(j, name, mem);
					}
					j += sizeof(u32);
				}
			}
			continue;

		/* Music registers */
		case IXGBE_RMCS:
			sprintf(name, "RMCS"); break;
		case IXGBE_DPMCS:
			sprintf(name, "DPMCS"); break;
		case IXGBE_PDPMCS:
			sprintf(name, "PDPMCS"); break;
		case IXGBE_RUPPBMR:
			sprintf(name, "RUPPBMR"); break;
		case IXGBE_RT2CR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RT2CR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RT2SR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RT2SR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TDTQ2TCCR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TDTQ2TCCR[%d]", n);
				printit32(j, name, mem);
				j += 0x40;
			}
			continue;
		case IXGBE_TDTQ2TCSR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TDTQ2TCSR[%d]", n);
				printit32(j, name, mem);
				j += 0x40;
			}
			continue;
		case IXGBE_TDPT2TCCR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TDPT2TCCR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TDPT2TCSR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TDPT2TCSR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* Stats registers */
		case IXGBE_CRCERRS:
			if (!clr) continue;
			sprintf(name, "CRCERRS"); break;
		case IXGBE_ILLERRC:
			if (!clr) continue;
			sprintf(name, "ILLERRC"); break;
		case IXGBE_ERRBC:
			if (!clr) continue;
			sprintf(name, "ERRBC"); break;
		case IXGBE_MSPDC:
			if (!clr) continue;
			sprintf(name, "MSPDC"); break;
		case IXGBE_MPC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MPC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MLFC:
			if (!clr) continue;
			sprintf(name, "MLFC"); break;
		case IXGBE_MRFC:
			if (!clr) continue;
			sprintf(name, "MRFC"); break;
		case IXGBE_RLEC:
			if (!clr) continue;
			sprintf(name, "RLEC"); break;
		case IXGBE_LXONTXC:
			if (!clr) continue;
			sprintf(name, "LXONTXC"); break;
		case IXGBE_LXONRXC:
			if (!clr) continue;
			sprintf(name, "LXONRXC"); break;
		case IXGBE_LXOFFTXC:
			if (!clr) continue;
			sprintf(name, "LXOFFTXC"); break;
		case IXGBE_LXOFFRXC:
			if (!clr) continue;
			sprintf(name, "LXOFFRXC"); break;
		case IXGBE_PXONTXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXONTXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXONRXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXONRXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXOFFTXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXOFFTXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PXOFFRXC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PXOFFRXC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PRC64:
			if (!clr) continue;
			sprintf(name, "PRC64"); break;
		case IXGBE_PRC127:
			if (!clr) continue;
			sprintf(name, "PRC127"); break;
		case IXGBE_PRC255:
			if (!clr) continue;
			sprintf(name, "PRC255"); break;
		case IXGBE_PRC511:
			if (!clr) continue;
			sprintf(name, "PRC511"); break;
		case IXGBE_PRC1023:
			if (!clr) continue;
			sprintf(name, "PRC1023"); break;
		case IXGBE_PRC1522:
			if (!clr) continue;
			sprintf(name, "PRC1522"); break;
		case IXGBE_GPRC:
			if (!clr) continue;
			sprintf(name, "GPRC"); break;
		case IXGBE_BPRC:
			if (!clr) continue;
			sprintf(name, "BPRC"); break;
		case IXGBE_MPRC:
			if (!clr) continue;
			sprintf(name, "MPRC"); break;
		case IXGBE_GPTC:
			if (!clr) continue;
			sprintf(name, "GPTC"); break;
		case IXGBE_GORCL:
			if (!clr) continue;
			sprintf(name, "GORCL"); break;
		case IXGBE_GORCH:
			if (!clr) continue;
			sprintf(name, "GORCH"); break;
		case IXGBE_GOTCL:
			if (!clr) continue;
			sprintf(name, "GOTCL"); break;
		case IXGBE_GOTCH:
			if (!clr) continue;
			sprintf(name, "GOTCH"); break;
		case IXGBE_RNBC(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RNBC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RUC:
			if (!clr) continue;
			sprintf(name, "RUC"); break;
		case IXGBE_RFC:
			if (!clr) continue;
			sprintf(name, "RFC"); break;
		case IXGBE_ROC:
			if (!clr) continue;
			sprintf(name, "ROC"); break;
		case IXGBE_RJC:
			if (!clr) continue;
			sprintf(name, "RJC"); break;
		case IXGBE_MNGPRC:
			if (!clr) continue;
			sprintf(name, "MNGPRC"); break;
		case IXGBE_MNGPDC:
			if (!clr) continue;
			sprintf(name, "MNGPDC"); break;
		case IXGBE_MNGPTC:
			if (!clr) continue;
			sprintf(name, "MNGPTC"); break;
		case IXGBE_TORL:
			if (!clr) continue;
			sprintf(name, "TORL"); break;
		case IXGBE_TORH:
			if (!clr) continue;
			sprintf(name, "TORH"); break;
		case IXGBE_TPR:
			if (!clr) continue;
			sprintf(name, "TPR"); break;
		case IXGBE_TPT:
			if (!clr) continue;
			sprintf(name, "TPT"); break;
		case IXGBE_PTC64:
			if (!clr) continue;
			sprintf(name, "PTC64"); break;
		case IXGBE_PTC127:
			if (!clr) continue;
			sprintf(name, "PTC127"); break;
		case IXGBE_PTC255:
			if (!clr) continue;
			sprintf(name, "PTC255"); break;
		case IXGBE_PTC511:
			if (!clr) continue;
			sprintf(name, "PTC511"); break;
		case IXGBE_PTC1023:
			if (!clr) continue;
			sprintf(name, "PTC1023"); break;
		case IXGBE_PTC1522:
			if (!clr) continue;
			sprintf(name, "PTC1522"); break;
		case IXGBE_MPTC:
			if (!clr) continue;
			sprintf(name, "MPTC"); break;
		case IXGBE_BPTC:
			if (!clr) continue;
			sprintf(name, "BPTC"); break;
		case IXGBE_XEC:
			if (!clr) continue;
			sprintf(name, "XEC"); break;
		case IXGBE_RQSMR(0):
			if (!clr) continue;
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "RQSMR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TQSMR(0):
			if (!clr) continue;
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TQSMR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_QPRC(0):
			if (!clr) continue;
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "QPRC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "QBRC[%d]", n);
				printit32(j, name, mem);
				j += 0x3c;
			}
			continue;
		case IXGBE_QPTC(0):
			if (!clr) continue;
			for (j=i, n=0; n<16; n++) {
				sprintf(name, "QPTC[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "QBTC[%d]", n);
				printit32(j, name, mem);
				j += 0x3c;
			}
			continue;

		/* Management */
		case IXGBE_MAVTV(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MAVTV[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MFUTP(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MFUTP[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MANC:
			sprintf(name, "MANC"); break;
		case IXGBE_MFVAL:
			sprintf(name, "MFVAL"); break;
		case IXGBE_MANC2H:
			sprintf(name, "MAN2CH"); break;
		case IXGBE_MDEF(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "MDEF[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_MIPAF:
			sprintf(name, "MIPAF"); break;
		case IXGBE_MMAL(0):
			for (j=i, n=0; n<4; n++) {
				sprintf(name, "MMAL[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
				sprintf(name, "MMAH[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_FTFT:
			for (j=i, m=0; m<4; m++) {
				for (n=0; n<32; n++) {
					sprintf(name, "FTFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					n++;
					sprintf(name, "FTFT[%d] DW%d", m, n);
					printit32(j, name, mem);
					j += sizeof(u32);
					sprintf(name, "FTFT[%d] Mask[%d:%d]", m,
					        (n*4+3), ((n-1)*4));
					printit8(j, name, mem);
					j += sizeof(u32);
					if (n == 31) {
						sprintf(name, "FTFT[%d] Length", m);
						printit32(j, name, mem);
					}
					j += sizeof(u32);
				}
			}
			continue;

		/* ARC Subsystem registers */
#if 0
		case IXGBE_HICR:
			sprintf(name, "HICR"); break;
#endif
		case IXGBE_FWSTS:
			sprintf(name, "FWSTS"); break;
		case IXGBE_HSMC0R:
			sprintf(name, "HSMCOR"); break;
		case IXGBE_HSMC1R:
			sprintf(name, "HSMC1R"); break;
		case IXGBE_SWSR:
			sprintf(name, "SWSR"); break;
		case IXGBE_HFDR:
			sprintf(name, "HFDR"); break;
		case IXGBE_FLEX_MNG:
			for (j=i, n=0; n<447; n++) {
				sprintf(name, "FLEX_MNG[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;

		/* PCI-E registers */
		case IXGBE_GCR:
			sprintf(name, "GCR"); break;
		case IXGBE_GTV:
			sprintf(name, "GTV"); break;
		case IXGBE_FUNCTAG:
			sprintf(name, "FUNCTAG"); break;
		case IXGBE_GLT:
			sprintf(name, "GLT"); break;
		case IXGBE_GSCL_1:
			sprintf(name, "GSCL_1"); break;
		case IXGBE_GSCL_2:
			sprintf(name, "GSCL_2"); break;
		case IXGBE_GSCL_3:
			sprintf(name, "GSCL_3"); break;
		case IXGBE_GSCL_4:
			sprintf(name, "GSCL_4"); break;
		case IXGBE_GSCN_0:
			sprintf(name, "GSCN_0"); break;
		case IXGBE_GSCN_1:
			sprintf(name, "GSCN_1"); break;
		case IXGBE_GSCN_2:
			sprintf(name, "GSCN_2"); break;
		case IXGBE_GSCN_3:
			sprintf(name, "GSCN_3"); break;
		case IXGBE_FACTPS:
			sprintf(name, "FACTPS"); break;
		case IXGBE_PCIEANACTL:
			sprintf(name, "PCIEANACTL"); break;
		case IXGBE_FWSM:
			sprintf(name, "FWSM"); break;
		case IXGBE_GSSR:
			sprintf(name, "GSSR"); break;
		case IXGBE_MREVID:
			sprintf(name, "MREVID"); break;
		case IXGBE_DCA_ID:
			sprintf(name, "DCA_ID"); break;
		case IXGBE_DCA_CTRL:
			sprintf(name, "DCA_CTRL"); break;

		/* Diagnostic Registers */
		case IXGBE_RDSTATCTL:
			sprintf(name, "RDSTATCTL"); break;
		case IXGBE_RDSTAT(0):
			if (!clr) continue;
			for (j=i, n=0; n<7; n++) {
				sprintf(name, "RDSTAT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RDHMPN:
			sprintf(name, "RDHMPN"); break;
		case IXGBE_RIC_DW(0):
			sprintf(name, "RIC_DW0"); break;
		case IXGBE_RIC_DW(1):
			sprintf(name, "RIC_DW1"); break;
		case IXGBE_RIC_DW(2):
			sprintf(name, "RIC_DW2"); break;
		case IXGBE_RIC_DW(3):
			sprintf(name, "RIC_DW3"); break;
		case IXGBE_RDPROBE:
			sprintf(name, "RDPROBE"); break;
		case IXGBE_TDSTATCTL:
			sprintf(name, "TDSTATCTL"); break;
		case IXGBE_TDSTAT(0):
			if (!clr) continue;
			for (j=i, n=0; n<7; n++) {
				sprintf(name, "TDSTAT[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TDHMPN:
			sprintf(name, "TDHMPN"); break;
		case IXGBE_TIC_DW(0):
			sprintf(name, "TIC_DW0"); break;
		case IXGBE_TIC_DW(1):
			sprintf(name, "TIC_DW1"); break;
		case IXGBE_TIC_DW(2):
			sprintf(name, "TIC_DW2"); break;
		case IXGBE_TIC_DW(3):
			sprintf(name, "TIC_DW3"); break;
		case IXGBE_TDPROBE:
			sprintf(name, "TDPROBE"); break;
		case IXGBE_TXBUFCTRL:
			sprintf(name, "TXBUFCTRL"); break;
		case IXGBE_TXBUFDATA0:
			sprintf(name, "TXBUFDATA0"); break;
		case IXGBE_TXBUFDATA1:
			sprintf(name, "TXBUFDATA1"); break;
		case IXGBE_TXBUFDATA2:
			sprintf(name, "TXBUFDATA2"); break;
		case IXGBE_TXBUFDATA3:
			sprintf(name, "TXBUFDATA3"); break;
		case IXGBE_RXBUFCTRL:
			sprintf(name, "RXBUFCTRL"); break;
		case IXGBE_RXBUFDATA0:
			sprintf(name, "RXBUFDATA0"); break;
		case IXGBE_RXBUFDATA1:
			sprintf(name, "RXBUFDATA1"); break;
		case IXGBE_RXBUFDATA2:
			sprintf(name, "RXBUFDATA2"); break;
		case IXGBE_RXBUFDATA3:
			sprintf(name, "RXBUFDATA3"); break;
		case IXGBE_PCIE_DIAG(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "PCIE_DIAG[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RFVAL:
			sprintf(name, "RFVAL"); break;
		case IXGBE_MDFTC1:
			sprintf(name, "MDFTC1"); break;
		case IXGBE_MDFTC2:
			sprintf(name, "MDFTC2"); break;
		case IXGBE_MDFTFIFO1:
			sprintf(name, "MDFTFIFO1"); break;
		case IXGBE_MDFTFIFO2:
			sprintf(name, "MDFTFIFO2"); break;
		case IXGBE_MDFTS:
			sprintf(name, "MDFTS"); break;
		case IXGBE_RXDATAWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXDATAWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXDESCWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXDESCWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXDATARDPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXDATARDPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_RXDESCRDPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "RXDESCRDPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TXDATAWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXDATAWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TXDESCWRPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXDESCWRPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TXDATARDPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXDATARDPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_TXDESCRDPTR(0):
			for (j=i, n=0; n<8; n++) {
				sprintf(name, "TXDESCRDPTR[%d]", n);
				printit32(j, name, mem);
				j += sizeof(u32);
			}
			continue;
		case IXGBE_PCIEECCCTL:
			sprintf(name, "PCIEECCCTL"); break;
		case IXGBE_PBTXECC:
			sprintf(name, "PBTXECC"); break;
		case IXGBE_PBRXECC:
			sprintf(name, "PBRXECC"); break;
		case IXGBE_GHECCR:
			sprintf(name, "GHECCR"); break;

		/* MAC Registers */
		case IXGBE_PCS1GCFIG:
			sprintf(name, "PCS1GCFIG"); break;
		case IXGBE_PCS1GLCTL:
			sprintf(name, "PCS1GLCTL"); break;
		case IXGBE_PCS1GLSTA:
			sprintf(name, "PCS1GLSTA"); break;
		case IXGBE_PCS1GDBG0:
			sprintf(name, "PCS1GDBG0"); break;
		case IXGBE_PCS1GDBG1:
			sprintf(name, "PCS1GDBG1"); break;
		case IXGBE_PCS1GANA:
			sprintf(name, "PCS1GANA"); break;
		case IXGBE_PCS1GANLP:
			sprintf(name, "PCS1GANLP"); break;
		case IXGBE_PCS1GANNP:
			sprintf(name, "PCS1GANNP"); break;
		case IXGBE_PCS1GANLPNP:
			sprintf(name, "PCS1GANLPNP"); break;
		case IXGBE_HLREG0:
			sprintf(name, "HLREG0"); break;
		case IXGBE_HLREG1:
			sprintf(name, "HLREG1"); break;
		case IXGBE_PAP:
			sprintf(name, "PAP"); break;
		case IXGBE_MACA:
			sprintf(name, "MACA"); break;
		case IXGBE_APAE:
			sprintf(name, "APAE"); break;
		case IXGBE_ARD:
			sprintf(name, "ARD"); break;
		case IXGBE_AIS:
			sprintf(name, "AIS"); break;
		case IXGBE_MSCA:
			sprintf(name, "MSCA"); break;
		case IXGBE_MSRWD:
			sprintf(name, "MSRWD"); break;
		case IXGBE_MLADD:
			sprintf(name, "MLADD"); break;
		case IXGBE_MHADD:
			sprintf(name, "MHADD"); break;
		case IXGBE_TREG:
			sprintf(name, "TREG"); break;
		case IXGBE_PCSS1:
			sprintf(name, "PCSS1"); break;
		case IXGBE_PCSS2:
			sprintf(name, "PCSS2"); break;
		case IXGBE_XPCSS:
			sprintf(name, "XPCSS"); break;
		case IXGBE_SERDESC:
			sprintf(name, "SERDESC"); break;
		case IXGBE_MACS:
			sprintf(name, "MACS"); break;
		case IXGBE_AUTOC:
			sprintf(name, "AUTOC"); break;
		case IXGBE_LINKS:
			sprintf(name, "LINKS"); break;
		case IXGBE_AUTOC2:
			sprintf(name, "AUTOC2"); break;
		case IXGBE_AUTOC3:
			sprintf(name, "AUTOC3"); break;
		case IXGBE_ANLP1:
			sprintf(name, "ANLP1"); break;
		case IXGBE_ANLP2:
			sprintf(name, "ANLP2"); break;
		case IXGBE_ATLASCTL:
			sprintf(name, "ATLASCTL"); break;
		default:
			continue;
		}
		printit32(i, name, mem);
	}
}

// vi:ts=4:sw=4:ht=4:
